OC.L10N.register(
    "logreader",
    {
    "Error" : "Error",
    "Copy" : "Copy"
},
"nplurals=1; plural=0;");
